==> doxygen-1.5.7.1.src.tar.gz: doxygen-1.5.7.1/src/layout_default.h <==
"<doxygenlayout version=\"1.0\">\n"
"  <!-- Navigation index tabs for HTML output -->\n"
"  <navindex>\n"
"    <tab type=\"mainpage\" visible=\"yes\" title=\"\"/>\n"
"    <tab type=\"pages\" visible=\"yes\" title=\"\"/>\n"
"    <tab type=\"modules\" visible=\"yes\" title=\"\"/>\n"
"    <tab type=\"namespaces\" visible=\"yes\" title=\"\">\n"
"      <tab type=\"namespaces\" visible=\"yes\" title=\"\"/>\n"
"      <tab type=\"namespacemembers\" visible=\"yes\" title=\"\"/>\n"
"    </tab>\n"
"    <tab type=\"classes\" visible=\"yes\" title=\"\">\n"
"      <tab type=\"classes\" visible=\"yes\" title=\"\"/>\n"
"      <tab type=\"classindex\" visible=\"$ALPHABETICAL_INDEX\" title=\"\"/> \n"
"      <tab type=\"hierarchy\" visible=\"yes\" title=\"\"/>\n"
"      <tab type=\"classmembers\" visible=\"yes\" title=\"\"/>\n"
"    </tab>\n"
"    <tab type=\"files\" visible=\"yes\" title=\"\">\n"
"      <tab type=\"files\" visible=\"yes\" title=\"\"/>\n"
"      <tab type=\"globals\" visible=\"yes\" title=\"\"/>\n"
"    </tab>\n"
"    <tab type=\"dirs\" visible=\"yes\" title=\"\"/>\n"
"    <tab type=\"examples\" visible=\"yes\" title=\"\"/>  \n"
"  </navindex>\n"
"\n"
"  <!-- Layout definition for a class page -->\n"
"  <class>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <includes visible=\"$SHOW_INCLUDE_FILES\"/>\n"
"    <inheritancegraph visible=\"$CLASS_GRAPH\"/>\n"
"    <collaborationgraph visible=\"$COLLABORATION_GRAPH\"/>\n"
"    <allmemberslink visible=\"yes\"/>\n"
"    <memberdecl>\n"
"      <membergroups visible=\"yes\"/>\n"
"      <nestedclasses visible=\"yes\" title=\"\"/>\n"
"      <publictypes title=\"\"/>\n"
"      <publicslots title=\"\"/>\n"
"      <signals title=\"\"/>\n"
"      <publicmethods title=\"\"/>\n"
"      <publicstaticmethods title=\"\"/>\n"
"      <publicattributes title=\"\"/>\n"
"      <publicstaticattributes title=\"\"/>\n"
"      <protectedtypes title=\"\"/>\n"
"      <protectedslots title=\"\"/>\n"
"      <protectedmethods title=\"\"/>\n"
"      <protectedstaticmethods title=\"\"/>\n"
"      <protectedattributes title=\"\"/>\n"
"      <protectedstaticattributes title=\"\"/>\n"
"      <packagetypes title=\"\"/>\n"
"      <packagemethods title=\"\"/>\n"
"      <packagestaticmethods title=\"\"/>\n"
"      <packageattributes title=\"\"/>\n"
"      <packagestaticattributes title=\"\"/>\n"
"      <properties title=\"\"/>\n"
"      <events title=\"\"/>\n"
"      <privatetypes title=\"\"/>\n"
"      <privateslots title=\"\"/>\n"
"      <privatemethods title=\"\"/>\n"
"      <privatestaticmethods title=\"\"/>\n"
"      <privateattributes title=\"\"/>\n"
"      <privatestaticattributes title=\"\"/>\n"
"      <friends title=\"\"/>\n"
"      <related title=\"\" subtitle=\"\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"    <memberdef>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <constructors title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <related title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"      <properties title=\"\"/>\n"
"      <events title=\"\"/>\n"
"    </memberdef>\n"
"    <usedfiles visible=\"$SHOW_USED_FILES\"/>\n"
"    <authorsection visible=\"yes\"/>\n"
"  </class>\n"
"\n"
"  <!-- Layout definition for a namespace page -->\n"
"  <namespace>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <memberdecl>\n"
"      <nestednamespaces visible=\"yes\" title=\"\"/>\n"
"      <classes visible=\"yes\" title=\"\"/>\n"
"      <membergroups visible=\"yes\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"    <memberdef>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"    </memberdef>\n"
"    <authorsection visible=\"yes\"/>\n"
"  </namespace>\n"
"\n"
"  <!-- Layout definition for a file page -->\n"
"  <file>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <includes visible=\"$SHOW_INCLUDE_FILES\"/>\n"
"    <includegraph visible=\"$INCLUDE_GRAPH\"/>\n"
"    <includedbygraph visible=\"$INCLUDED_BY_GRAPH\"/>\n"
"    <sourcelink visible=\"yes\"/>\n"
"    <memberdecl>\n"
"      <classes visible=\"yes\" title=\"\"/>\n"
"      <namespaces visible=\"yes\" title=\"\"/>\n"
"      <defines title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"    <memberdef>\n"
"      <defines title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"    </memberdef>\n"
"    <authorsection/>\n"
"  </file>\n"
"\n"
"  <!-- Layout definition for a group page -->\n"
"  <group>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <groupgraph visible=\"$GROUP_GRAPHS\"/>\n"
"    <memberdecl>\n"
"      <classes visible=\"yes\" title=\"\"/>\n"
"      <namespaces visible=\"yes\" title=\"\"/>\n"
"      <dirs visible=\"yes\" title=\"\"/>\n"
"      <nestedgroups visible=\"yes\" title=\"\"/>\n"
"      <files visible=\"yes\" title=\"\"/>\n"
"      <defines title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <enumvalues title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"      <signals title=\"\"/>\n"
"      <publicslots title=\"\"/>\n"
"      <protectedslots title=\"\"/>\n"
"      <privateslots title=\"\"/>\n"
"      <events title=\"\"/>\n"
"      <properties title=\"\"/>\n"
"      <friends title=\"\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"    <memberdef>\n"
"      <pagedocs/>\n"
"      <defines title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <enumvalues title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"      <signals title=\"\"/>\n"
"      <publicslots title=\"\"/>\n"
"      <protectedslots title=\"\"/>\n"
"      <privateslots title=\"\"/>\n"
"      <events title=\"\"/>\n"
"      <properties title=\"\"/>\n"
"      <friends title=\"\"/>\n"
"    </memberdef>\n"
"    <authorsection visible=\"yes\"/>\n"
"  </group>\n"
"\n"
"  <!-- Layout definition for a directory page -->\n"
"  <directory>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <directorygraph visible=\"yes\"/>\n"
"    <memberdecl>\n"
"      <dirs visible=\"yes\"/>\n"
"      <files visible=\"yes\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"  </directory>\n"
"</doxygenlayout>\n"

==> doxygen-1.7.5.src.tar.gz: doxygen-1.7.5/src/layout_default.h <==
"<doxygenlayout version=\"1.0\">\n"
"  <!-- Navigation index tabs for HTML output -->\n"
"  <navindex>\n"
"    <tab type=\"mainpage\" visible=\"yes\" title=\"\"/>\n"
"    <tab type=\"pages\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"    <tab type=\"modules\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"    <tab type=\"namespaces\" visible=\"yes\" title=\"\">\n"
"      <tab type=\"namespaces\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"      <tab type=\"namespacemembers\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"    </tab>\n"
"    <tab type=\"classes\" visible=\"yes\" title=\"\">\n"
"      <tab type=\"classes\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"      <tab type=\"classindex\" visible=\"$ALPHABETICAL_INDEX\" title=\"\"/> \n"
"      <tab type=\"hierarchy\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"      <tab type=\"classmembers\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"    </tab>\n"
"    <tab type=\"files\" visible=\"yes\" title=\"\">\n"
"      <tab type=\"files\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"      <tab type=\"globals\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"    </tab>\n"
"    <tab type=\"dirs\" visible=\"yes\" title=\"\" intro=\"\"/>\n"
"    <tab type=\"examples\" visible=\"yes\" title=\"\" intro=\"\"/>  \n"
"  </navindex>\n"
"\n"
"  <!-- Layout definition for a class page -->\n"
"  <class>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <includes visible=\"$SHOW_INCLUDE_FILES\"/>\n"
"    <inheritancegraph visible=\"$CLASS_GRAPH\"/>\n"
"    <collaborationgraph visible=\"$COLLABORATION_GRAPH\"/>\n"
"    <allmemberslink visible=\"yes\"/>\n"
"    <memberdecl>\n"
"      <nestedclasses visible=\"yes\" title=\"\"/>\n"
"      <publictypes title=\"\"/>\n"
"      <publicslots title=\"\"/>\n"
"      <signals title=\"\"/>\n"
"      <publicmethods title=\"\"/>\n"
"      <publicstaticmethods title=\"\"/>\n"
"      <publicattributes title=\"\"/>\n"
"      <publicstaticattributes title=\"\"/>\n"
"      <protectedtypes title=\"\"/>\n"
"      <protectedslots title=\"\"/>\n"
"      <protectedmethods title=\"\"/>\n"
"      <protectedstaticmethods title=\"\"/>\n"
"      <protectedattributes title=\"\"/>\n"
"      <protectedstaticattributes title=\"\"/>\n"
"      <packagetypes title=\"\"/>\n"
"      <packagemethods title=\"\"/>\n"
"      <packagestaticmethods title=\"\"/>\n"
"      <packageattributes title=\"\"/>\n"
"      <packagestaticattributes title=\"\"/>\n"
"      <properties title=\"\"/>\n"
"      <events title=\"\"/>\n"
"      <privatetypes title=\"\"/>\n"
"      <privateslots title=\"\"/>\n"
"      <privatemethods title=\"\"/>\n"
"      <privatestaticmethods title=\"\"/>\n"
"      <privateattributes title=\"\"/>\n"
"      <privatestaticattributes title=\"\"/>\n"
"      <friends title=\"\"/>\n"
"      <related title=\"\" subtitle=\"\"/>\n"
"      <membergroups visible=\"yes\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"    <memberdef>\n"
"      <inlineclasses title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <constructors title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <related title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"      <properties title=\"\"/>\n"
"      <events title=\"\"/>\n"
"    </memberdef>\n"
"    <usedfiles visible=\"$SHOW_USED_FILES\"/>\n"
"    <authorsection visible=\"yes\"/>\n"
"  </class>\n"
"\n"
"  <!-- Layout definition for a namespace page -->\n"
"  <namespace>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <memberdecl>\n"
"      <nestednamespaces visible=\"yes\" title=\"\"/>\n"
"      <classes visible=\"yes\" title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"      <membergroups visible=\"yes\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"    <memberdef>\n"
"      <inlineclasses title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"    </memberdef>\n"
"    <authorsection visible=\"yes\"/>\n"
"  </namespace>\n"
"\n"
"  <!-- Layout definition for a file page -->\n"
"  <file>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <includes visible=\"$SHOW_INCLUDE_FILES\"/>\n"
"    <includegraph visible=\"$INCLUDE_GRAPH\"/>\n"
"    <includedbygraph visible=\"$INCLUDED_BY_GRAPH\"/>\n"
"    <sourcelink visible=\"yes\"/>\n"
"    <memberdecl>\n"
"      <classes visible=\"yes\" title=\"\"/>\n"
"      <namespaces visible=\"yes\" title=\"\"/>\n"
"      <defines title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"      <membergroups visible=\"yes\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"    <memberdef>\n"
"      <inlineclasses title=\"\"/>\n"
"      <defines title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"    </memberdef>\n"
"    <authorsection/>\n"
"  </file>\n"
"\n"
"  <!-- Layout definition for a group page -->\n"
"  <group>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <groupgraph visible=\"$GROUP_GRAPHS\"/>\n"
"    <memberdecl>\n"
"      <classes visible=\"yes\" title=\"\"/>\n"
"      <namespaces visible=\"yes\" title=\"\"/>\n"
"      <dirs visible=\"yes\" title=\"\"/>\n"
"      <nestedgroups visible=\"yes\" title=\"\"/>\n"
"      <files visible=\"yes\" title=\"\"/>\n"
"      <defines title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <enumvalues title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"      <signals title=\"\"/>\n"
"      <publicslots title=\"\"/>\n"
"      <protectedslots title=\"\"/>\n"
"      <privateslots title=\"\"/>\n"
"      <events title=\"\"/>\n"
"      <properties title=\"\"/>\n"
"      <friends title=\"\"/>\n"
"      <membergroups visible=\"yes\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"    <memberdef>\n"
"      <pagedocs/>\n"
"      <inlineclasses title=\"\"/>\n"
"      <defines title=\"\"/>\n"
"      <typedefs title=\"\"/>\n"
"      <enums title=\"\"/>\n"
"      <enumvalues title=\"\"/>\n"
"      <functions title=\"\"/>\n"
"      <variables title=\"\"/>\n"
"      <signals title=\"\"/>\n"
"      <publicslots title=\"\"/>\n"
"      <protectedslots title=\"\"/>\n"
"      <privateslots title=\"\"/>\n"
"      <events title=\"\"/>\n"
"      <properties title=\"\"/>\n"
"      <friends title=\"\"/>\n"
"    </memberdef>\n"
"    <authorsection visible=\"yes\"/>\n"
"  </group>\n"
"\n"
"  <!-- Layout definition for a directory page -->\n"
"  <directory>\n"
"    <briefdescription visible=\"yes\"/>\n"
"    <directorygraph visible=\"yes\"/>\n"
"    <memberdecl>\n"
"      <dirs visible=\"yes\"/>\n"
"      <files visible=\"yes\"/>\n"
"    </memberdecl>\n"
"    <detaileddescription title=\"\"/>\n"
"  </directory>\n"
"</doxygenlayout>\n"
